package com.example.testktor

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.activity.viewModels
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.matuletest.ui.auth.FirstScreen
import com.example.matuletest.ui.auth.SliderScreen
import com.example.testktor.ViewModel.MainViewModel
import com.example.testktor.screen.auth.AuthScreen
import com.example.testktor.screen.auth.ForgotPasswordScreen
import com.example.testktor.screen.main.MainSneakersScreen
import com.example.testktor.screen.auth.RegScreen
import com.example.testktor.screen.auth.ResetPasswordScreen
import com.example.testktor.screen.main.CategorySneakersScreen
import com.example.testktor.screen.main.FavouriteSneakersContent
import com.example.testktor.screen.main.FavouriteSneakersScreen
import com.example.testktor.screen.main.KorzinaSneakersContent
import com.example.testktor.screen.main.KorzinaSneakersScreen
import com.example.testktor.screen.main.PopularSneakersScreen
import com.example.testktor.screen.main.SuccessOrderSneakersScreen
//import com.example.testktor.auth.AuthScreen
//import com.example.testktor.auth.RegistrationScreen
import com.example.testktor.ui.theme.TestKtorTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        val viewModel: MainViewModel by viewModels()

        enableEdgeToEdge()
        setContent {
            TestKtorTheme {
                val navController = rememberNavController()

                NavHost(navController = navController, startDestination = "first_screen") {
                    composable("first_screen") {
                        FirstScreen(onNavigateToSliderScreen = {
                            navController.navigate("slider_screen")
                        })
                    }
                    composable("slider_screen") {
                        SliderScreen(onNavigateToAuthScreen = {
                            navController.navigate("auth_screen")
                        })
                    }
                    composable("auth_screen") {
                        AuthScreen(navController)
                    }
                    composable("registration_screen") {
                        RegScreen(navController)
                    }
                    composable("resetPassword_screen") {
                        ResetPasswordScreen(navController)
                    }
                    composable("forgotPassword_screen") {
                        ForgotPasswordScreen(navController)
                    }
                    composable("mainSneakers_screen") {
                        MainSneakersScreen(navController, viewModel)
                    }
                    composable("popularSneakers_screen") {
                        PopularSneakersScreen(navController, viewModel)
                    }
                    composable("categorySneakers_screen") {
                        CategorySneakersScreen(navController, viewModel)
                    }
                    composable("favouriteSneakers_screen") {
                        FavouriteSneakersScreen(navController, viewModel)
                    }
                    composable("korzinaSneakers_screen") {
                        KorzinaSneakersScreen(navController, viewModel)
                    }
                    composable("successOrderSneakers_screen") {
                        SuccessOrderSneakersScreen(navController, viewModel)
                    }
                }
            }
        }
    }
}

