package com.example.testktor

import android.util.Log
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import com.example.testktor.ui.theme.TestKtorTheme
import io.ktor.client.HttpClient
import io.ktor.client.engine.android.Android
import io.ktor.client.request.get
import io.ktor.client.request.headers
import io.ktor.client.request.post
import io.ktor.client.request.setBody
import io.ktor.client.statement.HttpResponse
import io.ktor.client.statement.bodyAsText
import io.ktor.client.utils.EmptyContent.contentType
import io.ktor.client.utils.EmptyContent.headers
import io.ktor.http.ContentType
import io.ktor.http.HttpHeaders
import io.ktor.http.contentType
import kotlinx.serialization.Contextual
import kotlinx.serialization.Serializable
import kotlinx.serialization.decodeFromString
import kotlinx.serialization.encodeToString
import kotlinx.serialization.json.Json
import java.math.BigDecimal
import java.sql.Time

suspend fun authUser(client: HttpClient, email: String, password: String): Boolean {
    try {
        val response: HttpResponse = client.post("http://10.0.2.2:8080/login") {
            contentType(ContentType.Application.Json)
            setBody(Json.encodeToString(mapOf("email" to email, "password" to password)))
        }

        val responseBody = response.bodyAsText()
        Log.d("authUser", "Response: $responseBody")

        val json = Json { ignoreUnknownKeys = true }
        val responseMap = json.decodeFromString<Map<String, String>>(responseBody)

        if (responseMap.containsKey("Token") && responseMap["Token"]!!.isNotEmpty()){
            Token = responseMap["Token"]!!
            return true
        }

        return false
    } catch (e: Exception) {
        Log.e("authUser", "Error during login request", e)
        return false
    }
}

suspend fun regUser(client: HttpClient, email: String, password: String, name: String): Boolean{
    try{
        val response: HttpResponse = client.post("http://10.0.2.2:8080/register"){
            contentType(ContentType.Application.Json)
            setBody(Json.encodeToString(mapOf("name" to name, "email" to email, "password" to password)))
        }

        val responseBody = response.bodyAsText()
        Log.d("regUser", "Response: $responseBody")

        val json = Json { ignoreUnknownKeys = true }
        val responseMap = json.decodeFromString<Map<String, String>>(responseBody)

//        return responseMap["message"] == "Регистрация успешна"
        return true
    } catch (e: Exception){
        Log.e("regUser", "Error during registration request", e)
        return false
    }
}

suspend fun forgotPassword(client: HttpClient, email: String): Boolean{
    try{
        val response: HttpResponse = client.post("http://10.0.2.2:8080/forgot-password"){
            contentType(ContentType.Application.Json)
            setBody(Json.encodeToString(mapOf("email" to email)))
        }

        val responseBody = response.bodyAsText()
        Log.d("forgotPassword", "Response: $responseBody")

        val json = Json { ignoreUnknownKeys = true }
        val responseMap = json.decodeFromString<Map<String, String>>(responseBody)

        return responseMap["message"] == "Код на восстановление пароля отправлен"
    } catch (e: Exception){
        Log.e("forgotPassword", "Error during forgotting password", e)
        return false
    }
}

suspend fun resetPassword(client: HttpClient, code: String, newPassword: String): Boolean{
    try{
        val response: HttpResponse = client.post("http://10.0.2.2:8080/reset-password"){
            contentType(ContentType.Application.Json)
            setBody(Json.encodeToString(mapOf("code" to code, "newPassword" to newPassword)))
        }

        val responseBody = response.bodyAsText()
        Log.d("resetPassword", "Response: $responseBody")

        val json = Json { ignoreUnknownKeys = true }
        val responseMap = json.decodeFromString<Map<String, String>>(responseBody)

        return responseMap["message"] == "Пароль успешно изменён"
    } catch (e: Exception){
        Log.e("resetPassword", "Error during resetting password", e)
        return false
    }
}

suspend fun getSneakers(client: HttpClient): SneakerCategoryResponse?{
    return try {
        val response: HttpResponse = client.get("http://10.0.2.2:8080/mainWindow") {
            headers {
                append(HttpHeaders.Authorization, "Bearer $Token")
            }
        }

        val responseBody = response.bodyAsText()
        Log.d("getSneakers", "Response: $responseBody")

        val json = Json { ignoreUnknownKeys = true }
        json.decodeFromString<SneakerCategoryResponse>(responseBody)

    } catch (e: Exception) {
        Log.e("getSneakers", "error fetching sneakers or category", e)
        null
    }
}

suspend fun buySneakers(client: HttpClient, order: BuySneakersRequest): Boolean {
    return try {
        val response: HttpResponse = client.post("http://10.0.2.2:8080/buySneakers") {
            headers {
                append(HttpHeaders.ContentType, "application/json")
            }
            setBody(Json.encodeToString(order))
        }

        val responseBody = response.bodyAsText()
        Log.d("buySneakers", "Response: $responseBody")

        val json = Json { ignoreUnknownKeys = true }
        val result = json.decodeFromString<Map<String, String>>(responseBody)

        result["message"] == "Куплено"

    } catch (e: Exception) {
        Log.e("buySneakers", "Ошибка при покупке кроссовок", e)
        false
    }
}
