package com.example.testktor.method.auth

import androidx.compose.foundation.Canvas
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.ClickableText
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material.icons.filled.Lock
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.testktor.ViewModel.ClickableTextVM
import com.example.testktor.ViewModel.TextFieldVM
import com.example.testktor.ViewModel.TextFieldWithHideVM

@Composable
fun TopBar(email: String,
           onEmailChange: (String) -> Unit,
           password: String,
           onPasswordChange: (String) -> Unit
){
    Text(
        text = "Привет!",
        style = TextStyle(fontSize = 32.sp, fontWeight = FontWeight.Medium),
        modifier = Modifier.height(60.dp).padding(bottom = 8.dp)
    )

    Text(
        text = "Заполните Свои Данные Или\nПродолжите Через Социальные Медиа",
        modifier = Modifier
            .fillMaxWidth()
            .padding(bottom = 20.dp),
        color = Color.Gray,
        style = TextStyle(fontSize = 18.sp, fontWeight = FontWeight.Light),
        textAlign = TextAlign.Center,
        softWrap = true,
        maxLines = 2
    )

    Spacer(modifier = Modifier.padding(top = 20.dp))

    Text(text = "Email", modifier = Modifier.padding(end = 280.dp))
    TextFieldVM(email, {onEmailChange(it)}, "xyz@gmail.com")
    Spacer(modifier = Modifier.padding(top = 20.dp))

    Text(text = "Password", modifier = Modifier.padding(end = 250.dp))
    TextFieldWithHideVM(password, {onPasswordChange(it)}, "******")
}

@Composable
fun Restore(navController: NavController) {
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .padding(bottom = 20.dp, end = 36.dp),
        horizontalArrangement = Arrangement.End
    ) {
        ClickableTextVM(
            "Восстановить",
            navController,
            "forgotPassword_screen",
            TextStyle(fontSize = 12.sp, color = Color.Gray)
        )
    }
}

@Composable
fun BotBar(navController: NavController) {
    Box(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp)
    ) {
        Row(
            modifier = Modifier
                .align(Alignment.BottomCenter)
                .padding(bottom = 30.dp),
            horizontalArrangement = Arrangement.Center
        ) {
            Text(
                text = "Вы впервые? ",
                style = TextStyle(fontSize = 16.sp, color = Color.Gray)
            )

            ClickableTextVM(
                "Создать пользователя",
                navController,
                "registration_screen",
                TextStyle(fontSize = 16.sp, color = Color.Black)
            )
        }
    }
}