package com.example.testktor.method.main

import android.util.Log
import androidx.compose.foundation.Canvas
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.testktor.SneakerShop
import com.example.testktor.ViewModel.MainViewModel

@Composable
fun TopWriteNavigationBar(navController: NavController, message: String, viewModel: MainViewModel) {
    Row (
        modifier = Modifier
            .fillMaxWidth()
            .padding(16.dp),
        verticalAlignment = Alignment.CenterVertically
    ){
        CategoryButtonBack(navController, "mainSneakers_screen", viewModel)

        Box(
            modifier = Modifier
                .fillMaxWidth()
                .weight(1f),
            contentAlignment = Alignment.Center
        ) {
            Text(
                text = message,
                fontSize = 30.sp
            )
        }
    }
}

@Composable
fun SneakerCategorySelection(sneakers: List<SneakerShop>, viewModel: MainViewModel) {
    Column(modifier = Modifier.fillMaxWidth()) {
        sneakers.chunked(2).forEach { sneakerPair ->
            Row(
                modifier = Modifier
                    .fillMaxWidth()
                    .padding(vertical = 8.dp),
                horizontalArrangement = Arrangement.SpaceEvenly
            ) {
                sneakerPair.forEach { sneakerShop ->
                    SneakerButton(
                        sneakerShop = sneakerShop,
                        isLiked = viewModel.isLiked(sneakerShop.sneaker.id),
                        isOrdered = viewModel.isOrdered(sneakerShop.sneaker.id),
                        onClick = { /* переход */ },
                        onFavoriteClick = {
                            viewModel.toggleLike(sneakerShop.sneaker.id)
                            val likedCount = viewModel.likedSneakers.values.count { it }
                            Log.d("SneakerLike", "Лайкнуто кроссовок: $likedCount")
                        },
                        onOrderClick = {
                            val sneakerId = sneakerShop.sneaker.id

                            if (!viewModel.isOrdered(sneakerId)) {
                                viewModel.toggleOrder(sneakerId)
                                viewModel.setSneakerQuantity(sneakerId, 1)
                            } else {
                                viewModel.toggleOrder(sneakerId)
                                viewModel.setSneakerQuantity(sneakerId, 0)
                            }

                            val orderCount = viewModel.orderedSneakers.values.count { it }
                            Log.d("SneakerOrder", "Добавлено в корзину кроссовок: $orderCount")
                        }
                    )
                }
            }
        }
    }
}

@Composable
fun CategoryButtonBack(navController: NavController, screen: String, viewModel: MainViewModel){
    IconButton(onClick = {
        viewModel.selectedCategory = null
        navController.navigate(screen) {
            popUpTo(screen) { inclusive = true }
        }
    }) {
        Box(
            contentAlignment = Alignment.Center,
            modifier = Modifier.size(56.dp)
        ) {
            Canvas(modifier = Modifier.matchParentSize()) {
                drawCircle(color = Color.LightGray)
            }
            Icon(
                imageVector = Icons.Default.ArrowBack,
                contentDescription = "Назад",
                modifier = Modifier.size(28.dp),
                tint = Color.Black
            )
        }
    }
}

