package com.example.testktor.method.main

import android.util.Log
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.aspectRatio
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.offset
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyRow
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.ClickableText
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Add
import androidx.compose.material.icons.filled.Favorite
import androidx.compose.material.icons.filled.FavoriteBorder
import androidx.compose.material.icons.filled.Home
import androidx.compose.material.icons.filled.Notifications
import androidx.compose.material.icons.filled.Person
import androidx.compose.material.icons.filled.Search
import androidx.compose.material.icons.filled.ShoppingCart
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import coil.compose.AsyncImage
import com.example.testktor.Category
import com.example.testktor.R
import com.example.testktor.SneakerShop
import com.example.testktor.ViewModel.MainViewModel

@Preview(showBackground = true)
@Composable
fun TopNavigationBar(){
    Row (
        modifier = Modifier
            .fillMaxWidth()
            .padding(16.dp),
        verticalAlignment = Alignment.CenterVertically
    ){
        IconButton(onClick = { /* TODO: действие кнопки */ }) {
            Image(
                painter = painterResource(id = R.drawable.hamburger),
                contentDescription = "menu",
                modifier = Modifier.size(40.dp)
            )
        }

        Box(
            modifier = Modifier
                .fillMaxWidth()
                .weight(1f),
            contentAlignment = Alignment.Center
        ) {
            Text(
                text = "Главная",
                fontSize = 30.sp
            )
        }

        IconButton(onClick = { /* TODO: действие кнопки */ }) {
            Image(
                painter = painterResource(id = R.drawable.frame31),
                contentDescription = "menu",
                modifier = Modifier.size(40.dp)
            )
        }
    }
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun Searchbar(searchBox: String, onSearchChange: (String) -> Unit){
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .padding(16.dp),
        verticalAlignment = Alignment.CenterVertically
    ){
        TextField(
            modifier = Modifier
                .width(300.dp)
                .height(70.dp)
                .padding(bottom = 16.dp),
            value = searchBox,
            onValueChange = { onSearchChange(it) },
            placeholder = {
                Text(
                    text = "Поиск",
                    color = Color.Gray,
                    fontSize = 14.sp
                )
            },
            colors = TextFieldDefaults.textFieldColors(
                containerColor = Color.White,
                focusedIndicatorColor = Color.Transparent,
                unfocusedIndicatorColor = Color.Transparent,
                cursorColor = Color.Black
            ),
            shape = RoundedCornerShape(12.dp),
            leadingIcon = {
                Icon(
                    imageVector = Icons.Default.Search,
                    contentDescription = "Search",
                    tint = Color.Gray
                )
            }
        )

        IconButton(onClick = { /* TODO: действие кнопки */ }) {
            Image(
                painter = painterResource(id = R.drawable.group12),
                contentDescription = "settings",
                modifier = Modifier.size(60.dp)
            )
        }
    }
}

@Composable
fun OverSmth(smth: String, navController: NavController?){
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .padding(16.dp),
        verticalAlignment = Alignment.CenterVertically
    ) {
        ClickableText(
            modifier = Modifier.weight(1f),
            text = buildAnnotatedString { append(smth) },
            onClick = {/* TODO: действие кнопки */},
            style = TextStyle(
                fontSize = 16.sp,
                color = Color.Black
            ),
        )

        ClickableText(
            text = buildAnnotatedString { append("Все") },
            onClick = { if (navController != null){
                navController.navigate("popularSneakers_screen")
            }},
            style = TextStyle(
                fontSize = 12.sp,
                color = Color.Cyan
            ),
        )
    }
}

@Preview(showBackground = true)
@Composable
fun SalesBar() {
    Column(
        modifier = Modifier
            .fillMaxWidth()
            .padding(16.dp)
    ) {
        OverSmth("Акции", null)

        Box(
            modifier = Modifier
                .fillMaxWidth()
                .height(160.dp)
                .background(Color(0xFFF7F7F9)),
            contentAlignment = Alignment.Center,
        ) {
            Image(
                painter = painterResource(id = R.drawable.img),
                contentDescription = "sales",
                modifier = Modifier.fillMaxSize(),
                contentScale = ContentScale.Fit
            )
        }
    }
}

@Composable
fun BottomNavigationBar(navController: NavController) {
    Box(
        modifier = Modifier.fillMaxSize(),
        contentAlignment = Alignment.BottomCenter
    ) {
        Image(
            painter = painterResource(id = R.drawable.bottom),
            contentDescription = null,
            contentScale = ContentScale.FillWidth,
            modifier = Modifier
                .fillMaxWidth()
                .aspectRatio(3f)
        )

        Row(
            modifier = Modifier
                .fillMaxWidth()
                .padding(bottom = 16.dp),
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.Center
        ) {
            IconButton(onClick = { /* TODO: действие кнопки */ }) {
                Icon(
                    imageVector = Icons.Default.Home,
                    contentDescription = "home",
                    modifier = Modifier.size(40.dp)
                )
            }
            Spacer(modifier = Modifier.width(20.dp))
            IconButton(onClick = { navController.navigate("favouriteSneakers_screen")}) {
                Icon(
                    imageVector = Icons.Default.FavoriteBorder,
                    contentDescription = "favourite",
                    modifier = Modifier.size(40.dp)
                )
            }
            Spacer(modifier = Modifier.width(20.dp))
            IconButton(
                onClick = { navController.navigate("korzinaSneakers_screen") },
                modifier = Modifier.offset(y = (-20).dp).size(80.dp)
            ) {
                Image(
                    painter = painterResource(id = R.drawable.group123),
                    contentDescription = "korzina",
                    modifier = Modifier.size(80.dp)
                )
            }
            Spacer(modifier = Modifier.width(20.dp))
            IconButton(onClick = { /* TODO: действие кнопки */ }) {
                Icon(
                    imageVector = Icons.Default.Notifications,
                    contentDescription = "notice",
                    modifier = Modifier.size(40.dp)
                )
            }
            Spacer(modifier = Modifier.width(20.dp))
            IconButton(onClick = { /* TODO: действие кнопки */ }) {
                Icon(
                    imageVector = Icons.Default.Person,
                    contentDescription = "profile",
                    modifier = Modifier.size(40.dp)
                )
            }
        }
    }
}

@Composable
fun CategorySelection(
    categories: List<Category>,
    selectedCategory: Category?,
    onCategorySelected: (Category?) -> Unit
) {
    LazyRow {
        items(categories) { category ->
            CategoryButton(
                category = category,
                isSelected = category == selectedCategory,
                onClick = {
                    if (selectedCategory == category) {
                        onCategorySelected(null)
                    } else {
                        onCategorySelected(category)
                    }
                }
            )
        }
    }
}

@Composable
fun CategoryButton(category: Category, isSelected: Boolean, onClick: () -> Unit) {
    Button(
        onClick = onClick,
        modifier = Modifier
            .padding(8.dp),
        colors = ButtonDefaults.buttonColors(
            containerColor = if (isSelected) Color.Cyan else Color.White
        )
    ) {
        Text(text = category.name, color = Color.Black)
    }
}

@Composable
fun SneakerSelection(sneakers: List<SneakerShop>, viewModel: MainViewModel) {
    Row(
        modifier = Modifier.fillMaxWidth(),
        horizontalArrangement = Arrangement.SpaceEvenly
    ) {
        sneakers.take(2).forEachIndexed { index ,sneakerShop ->
            SneakerButton(
                sneakerShop = sneakerShop,
                isLiked = viewModel.isLiked(sneakerShop.sneaker.id),
                isOrdered = viewModel.isOrdered(sneakerShop.sneaker.id),
                onClick = { /* переход */ },
                onFavoriteClick = {
                    viewModel.toggleLike(sneakerShop.sneaker.id)
                    val likedCount = viewModel.likedSneakers.values.count { it }
                    Log.d("SneakerLike", "Лайкнуто кроссовок: $likedCount")
                },
                onOrderClick = {
                    val sneakerId = sneakerShop.sneaker.id

                    if (!viewModel.isOrdered(sneakerId)) {
                        viewModel.toggleOrder(sneakerId)
                        viewModel.setSneakerQuantity(sneakerId, 1)
                    } else {
                        viewModel.toggleOrder(sneakerId)
                        viewModel.setSneakerQuantity(sneakerId, 0)
                    }

                    val orderCount = viewModel.orderedSneakers.values.count { it }
                    Log.d("SneakerOrder", "Добавлено в корзину кроссовок: $orderCount")
                }
            )
        }
    }
}

@Composable
fun SneakerButton(
    sneakerShop: SneakerShop,
    isLiked: Boolean,
    isOrdered: Boolean,
    onClick: () -> Unit,
    onFavoriteClick: () -> Unit,
    onOrderClick: () -> Unit
) {
    Box(modifier = Modifier.padding(8.dp)) {
        Button(
            onClick = onClick,
            modifier = Modifier
                .width(140.dp)
                .height(180.dp),
            colors = ButtonDefaults.buttonColors(
                containerColor = Color.White
            ),
            shape = RoundedCornerShape(12.dp)
        ) {
            Column(horizontalAlignment = Alignment.CenterHorizontally) {
                AsyncImage(
                    model = sneakerShop.sneaker.photo,
                    contentDescription = "Sneaker Image",
                    modifier = Modifier
                        .width(200.dp)
                        .height(90.dp)
                )
                Text(text = sneakerShop.sneaker.name, fontSize = 20.sp, color = Color.DarkGray)
                Text(text = "₽${sneakerShop.sneaker.cost}", fontSize = 15.sp, color = Color.Black)
            }
        }

        IconButton(
            onClick = onFavoriteClick,
            modifier = Modifier
                .align(Alignment.TopStart)
                .size(28.dp)
                .padding(4.dp)
        ) {
            val icon = if (isLiked) Icons.Default.Favorite else Icons.Default.FavoriteBorder
            Icon(imageVector = icon, contentDescription = "Favourite", tint = Color.Red)
        }
        IconButton(
            onClick = onOrderClick,
            modifier = Modifier
                .align(Alignment.BottomEnd)
                .size(32.dp)
                .padding(4.dp)
        ) {
            val iconRes = if (isOrdered) Icons.Default.ShoppingCart else Icons.Default.Add
            Icon(imageVector = iconRes, contentDescription = "Cart", tint = Color.Cyan)
        }
    }
}
