package com.example.testktor.screen.auth

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.testktor.ViewModel.ButtonBack
import com.example.testktor.authUser
import com.example.testktor.method.auth.BotBar
import com.example.testktor.method.auth.Restore
import com.example.testktor.method.auth.TopBar
import io.ktor.client.HttpClient
import io.ktor.client.engine.android.Android

@Composable
fun AuthScreen(navController: NavController) {
    var authSuccess by remember { mutableStateOf<String?>(null) }
    var email by remember { mutableStateOf("") }
    var password by remember { mutableStateOf("") }
    var shouldAuth by remember { mutableStateOf(false) }

    val client = HttpClient(Android)

    LaunchedEffect(shouldAuth) {
        if (shouldAuth) {
            val result = authUser(client, email, password)
            authSuccess = if (result) "Success" else "Failed"
            shouldAuth = false
        }
    }

    LaunchedEffect(authSuccess) {
        if (authSuccess == "Success") {
            navController.navigate("mainSneakers_screen") {
                popUpTo("auth_screen") { inclusive = true }
            }
        }
    }

    AuthContent(
        navController = navController,
        authSuccess = authSuccess,
        email = email,
        password = password,
        onAuth = { newEmail, newPassword ->
            email = newEmail
            password = newPassword
            shouldAuth = true
        }
    )
}

@Composable
fun AuthContent(
    navController: NavController,
    authSuccess: String?,
    email: String,
    password: String,
    onAuth: (String, String) -> Unit
) {
    var emailIn by remember { mutableStateOf(email) }
    var passwordIn by remember { mutableStateOf(password) }

    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {
        ButtonBack(navController, "slider_screen")

        Spacer(modifier = Modifier.height(20.dp))

        if (authSuccess == "Failed") {
            Text(
                text = "Ошибка авторизации",
                modifier = Modifier
                    .padding(start = 16.dp, top = 16.dp)
                    .align(Alignment.Start),
                color = Color.Red,
                style = TextStyle(fontSize = 18.sp, fontWeight = FontWeight.Bold)
            )
        }

        TopBar(emailIn, { emailIn = it }, passwordIn, { passwordIn = it })
        Restore(navController)

        Button(
            modifier = Modifier
                .width(350.dp)
                .height(50.dp),
            colors = androidx.compose.material3.ButtonDefaults.buttonColors(
                containerColor = Color(0xFF48B2E7),
                contentColor = Color.White
            ),
            onClick = { onAuth(emailIn, passwordIn) }
        ) {
            Text("Войти")
        }

        BotBar(navController)
    }
}
