package com.example.testktor.screen.auth

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.text.ClickableText
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.testktor.ViewModel.ButtonBack
import com.example.testktor.forgotPassword
import com.example.testktor.method.auth.BarForgot
import com.example.testktor.resetPassword
import io.ktor.client.HttpClient
import io.ktor.client.engine.android.Android

@Composable
fun ForgotPasswordScreen(navController: NavController) {
    var forgotSuccess by remember { mutableStateOf<String?>(null) }
    var email by remember { mutableStateOf("") }

    val client = HttpClient(Android)

    LaunchedEffect(email) {
        if (email.isNotEmpty()) {
            val result = forgotPassword(client, email)
            forgotSuccess = if (result) "Success" else "Failed"
        }
    }

    ForgotPasswordContent(navController, forgotSuccess, email) { newEmail ->
        email = newEmail
    }
}

@Composable
fun ForgotPasswordContent(
    navController: NavController,
    forgotSuccess: String?,
    email: String,
    onForgot: (String) -> Unit
) {
    var emailIn by remember { mutableStateOf(email) }

    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Top
    ) {
        ButtonBack(navController, "auth_screen")

        Spacer(modifier = Modifier.height(20.dp))

        if (forgotSuccess != null){
            if (forgotSuccess == "Success") {
                navController.navigate("resetPassword_screen")
            } else{
                Text(
                    text = "Error",
                    modifier = Modifier
                        .padding(start = 16.dp, top = 16.dp)
                        .align(Alignment.Start),
                    color = Color.Green,
                    style = TextStyle(fontSize = 18.sp, fontWeight = FontWeight.Bold)
                )
            }
        }

        BarForgot(emailIn){emailIn = it}

        Spacer(modifier = Modifier.padding(10.dp))

        Button(
            modifier = Modifier.width(350.dp).height(50.dp),
            colors = androidx.compose.material3.ButtonDefaults.buttonColors(
                containerColor = Color(0xFF48B2E7),
                contentColor = Color.White
            ),
            onClick = { onForgot(emailIn) }
        ) {
            Text("Отправить")
        }
    }
}
