package com.example.testktor.screen.auth

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.testktor.ViewModel.ButtonBack
import com.example.testktor.method.auth.BotBarReg
import com.example.testktor.method.auth.TopBarReg
import com.example.testktor.regUser
import io.ktor.client.HttpClient
import io.ktor.client.engine.android.Android

//@Composable
//fun RegScreen(navController: NavController) {
//    var regSuccess by remember { mutableStateOf<String?>(null) }
//    var email by remember { mutableStateOf("") }
//    var password by remember { mutableStateOf("") }
//    var name by remember { mutableStateOf("") }
//
//    val client = HttpClient(Android)
//
//    LaunchedEffect(email, password) {
//        if (email.isNotEmpty() && password.isNotEmpty()) {
//            val result = regUser(client, email, password, name)
//            regSuccess = if (result) "Success" else "Failed"
//        }
//    }
//
//    RegContent(navController, regSuccess, email, password, name) { newEmail, newPassword, newName ->
//        email = newEmail
//        password = newPassword
//        name = newName
//    }
//}

@Composable
fun RegScreen(navController: NavController) {
    var regSuccess by remember { mutableStateOf<String?>(null) }
    var email by remember { mutableStateOf("") }
    var password by remember { mutableStateOf("") }
    var name by remember { mutableStateOf("") }

    val client = HttpClient(Android)

    var shouldRegister by remember { mutableStateOf(false) }

    LaunchedEffect(shouldRegister) {
        if (shouldRegister) {
            val result = regUser(client, email, password, name)
            regSuccess = if (result) "Success" else "Failed"
            shouldRegister = false
        }
    }

    RegContent(
        navController = navController,
        regSuccess = regSuccess,
        email = email,
        password = password,
        name = name,
        onReg = { newEmail, newPassword, newName ->
            email = newEmail
            password = newPassword
            name = newName
            shouldRegister = true
        }
    )
}

@Composable
fun RegContent(
    navController: NavController,
    regSuccess: String?,
    email: String,
    password: String,
    name: String,
    onReg: (String, String, String) -> Unit
) {
    var emailIn by remember { mutableStateOf(email) }
    var passwordIn by remember { mutableStateOf(password) }
    var nameIn by remember { mutableStateOf(name) }

    LaunchedEffect(regSuccess) {
        if (regSuccess == "Success") {
            navController.navigate("auth_screen") {
                popUpTo("reg_screen") { inclusive = true }
            }
        }
    }

    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {
        ButtonBack(navController, "auth_screen")

        Spacer(modifier = Modifier.height(20.dp))

        if (regSuccess == "Failed") {
            Text(
                text = "Ошибка регистрации",
                modifier = Modifier
                    .padding(start = 16.dp, top = 16.dp)
                    .align(Alignment.Start),
                color = Color.Red,
                style = TextStyle(fontSize = 18.sp, fontWeight = FontWeight.Bold)
            )
        }

        TopBarReg(
            name = nameIn,
            onNameChange = { nameIn = it },
            email = emailIn,
            onEmailChange = { emailIn = it },
            password = passwordIn,
            onPasswordChange = { passwordIn = it }
        )

        Button(
            modifier = Modifier
                .width(350.dp)
                .height(50.dp),
            colors = androidx.compose.material3.ButtonDefaults.buttonColors(
                containerColor = Color(0xFF48B2E7),
                contentColor = Color.White
            ),
            onClick = {
                onReg(emailIn, passwordIn, nameIn)
            }
        ) {
            Text("Зарегистрироваться")
        }

        Spacer(modifier = Modifier.height(140.dp))

        BotBarReg(navController)
    }
}

//@Composable
//fun RegContent(
//    navController: NavController,
//    regSuccess: String?,
//    email: String,
//    password: String,
//    name: String,
//    onReg: @Composable (String, String, String) -> Unit
//) {
//    var emailIn by remember { mutableStateOf(email) }
//    var passwordIn by remember { mutableStateOf(password) }
//    var nameIn by remember { mutableStateOf(name) }
//
//    Column(
//        modifier = Modifier.fillMaxSize(),
//        horizontalAlignment = Alignment.CenterHorizontally,
//        verticalArrangement = Arrangement.Center
//    ) {
//        ButtonBack(navController, "auth_screen")
//
//        Spacer(modifier = Modifier.height(20.dp))
//
//        if (regSuccess != null){
//            if (regSuccess == "Success") {
//                navController.navigate("auth_screen")
//            } else{
//                Text(
//                    text = "Error",
//                    modifier = Modifier
//                        .padding(start = 16.dp, top = 16.dp)
//                        .align(Alignment.Start),
//                    color = Color.Green,
//                    style = TextStyle(fontSize = 18.sp, fontWeight = FontWeight.Bold)
//                )
//            }
//        }
//
//        TopBarReg(nameIn, {nameIn = it}, emailIn, {emailIn = it}, passwordIn, {passwordIn = it})
//
//        Button(
//            modifier = Modifier.width(350.dp).height(50.dp),
//            colors = androidx.compose.material3.ButtonDefaults.buttonColors(
//                containerColor = Color(0xFF48B2E7),
//                contentColor = Color.White
//            ),
//            onClick = { onReg(emailIn, passwordIn, nameIn) }
//        ) {
//            Text("Зарегистрироваться")
//        }
//
//        Spacer(modifier = Modifier.height(140.dp))
//
//        BotBarReg(navController)
//    }
//}
