package com.example.testktor.screen.auth

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.android.identity.cbor.Uint
import com.example.testktor.ViewModel.ButtonBack
import com.example.testktor.authUser
import com.example.testktor.method.auth.TextFieldsReset
import com.example.testktor.method.auth.TopBarReset
import com.example.testktor.resetPassword
import io.ktor.client.HttpClient
import io.ktor.client.engine.android.Android

@Composable
fun ResetPasswordScreen(navController: NavController) {
    var resetSuccess by remember { mutableStateOf<String?>(null) }
    var code by remember { mutableStateOf("") }
    var newPassword by remember { mutableStateOf("") }

    val client = HttpClient(Android)

    LaunchedEffect(code, newPassword) {
        if (code.isNotEmpty() && newPassword.isNotEmpty()) {
            val result = resetPassword(client, code, newPassword)
            resetSuccess = if (result) "Success" else "Failed"
        }
    }

    ResetPasswordContent(navController, resetSuccess, code, newPassword) { newCode, newNewPassword ->
        code = newCode
        newPassword = newNewPassword
    }
}

@Composable
fun ResetPasswordContent(
    navController: NavController,
    resetSuccess: String?,
    code: String,
    newPassword: String,
    onReset: (String, String) -> Unit
) {
    var codeIn by remember { mutableStateOf(code) }
    var newPasswordIn by remember { mutableStateOf(newPassword) }

    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Top
    ) {
        ButtonBack(navController, "auth_screen")

        Spacer(modifier = Modifier.height(20.dp))

        if (resetSuccess != null){
            if (resetSuccess == "Success") {
                navController.navigate("auth_screen")
            } else{
                Text(
                    text = "Error",
                    modifier = Modifier
                        .padding(start = 16.dp, top = 16.dp)
                        .align(Alignment.Start),
                    color = Color.Green,
                    style = TextStyle(fontSize = 18.sp, fontWeight = FontWeight.Bold)
                )
            }
        }

        TopBarReset()
        TextFieldsReset(codeIn, {codeIn = it}, newPasswordIn, {newPasswordIn = it})

        Button(
            modifier = Modifier.width(350.dp).height(50.dp),
            colors = androidx.compose.material3.ButtonDefaults.buttonColors(
                containerColor = Color(0xFF48B2E7),
                contentColor = Color.White
            ),
            onClick = { onReset(codeIn, newPasswordIn) }
        ) {
            Text("Восстановить")
        }
    }
}
