package com.example.testktor.screen.main

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.testktor.SneakerShop
import com.example.testktor.ViewModel.MainViewModel
import com.example.testktor.method.main.CategorySelection
import com.example.testktor.method.main.SneakerCategorySelection
import com.example.testktor.method.main.TopWriteNavigationBar


@Composable
fun CategorySneakersScreen(
    navController: NavController,
    viewModel: MainViewModel
) {
    Box(
        modifier = Modifier
            .fillMaxSize()
            .background(Color(0xFFF7F7F9))
    ) {
        CategorySneakersContent(navController, viewModel)
    }
}

@Composable
fun CategorySneakersContent(
    navController: NavController,
    viewModel: MainViewModel
){
    var sneakers by remember(viewModel.selectedCategory) {
        mutableStateOf(
            viewModel.sneakersCategories.sneakers.filter {
                viewModel.selectedCategory == null || it.categoryId == viewModel.selectedCategory?.id
            }.map { sneaker ->
                SneakerShop(sneaker, false, false)
            }
        )
    }

    Column {
        TopWriteNavigationBar(navController, "outdoor", viewModel)

        Text(text = "Категории", fontSize = 16.sp)

        CategorySelection(
            categories = viewModel.sneakersCategories.categories,
            selectedCategory = viewModel.selectedCategory,
            onCategorySelected = { category ->
                viewModel.selectedCategory = category
            }
        )

        SneakerCategorySelection(sneakers, viewModel)
    }
}
