package com.example.testktor.screen.main

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.testktor.SneakerCategoryResponse
import com.example.testktor.SneakerShop
import com.example.testktor.ViewModel.MainViewModel
import com.example.testktor.method.main.BottomNavigationBar
import com.example.testktor.method.main.CategorySelection
import com.example.testktor.method.main.OverSmth
import com.example.testktor.method.main.SalesBar
import com.example.testktor.method.main.Searchbar
import com.example.testktor.method.main.SneakerSelection
import com.example.testktor.method.main.TopNavigationBar

@Composable
fun MainSneakersScreen(navController: NavController, viewModel: MainViewModel) {
    val sneakersCategories = viewModel.sneakersCategories
    val searchBox by remember { mutableStateOf("") }

    Box(
        modifier = Modifier
            .fillMaxSize()
            .background(Color(0xFFF7F7F9))
    ) {
        SneakersContent(sneakersCategories, searchBox, navController, viewModel)
    }
}

@Composable
fun SneakersContent(
    sneakersCategories: SneakerCategoryResponse,
    searchBox: String,
    navController: NavController,
    viewModel: MainViewModel
) {
    var searchBoxIn by remember { mutableStateOf(searchBox) }
    var sneakers by remember(viewModel.sneakersCategories) {
        mutableStateOf(
            viewModel.sneakersCategories.sneakers.map { sneaker ->
                SneakerShop(sneaker, false, false)
            }
        )
    }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
    ) {
        TopNavigationBar()
        Searchbar(searchBoxIn, { searchBoxIn = it })

        Column {
            Text(text = "Категории", fontSize = 16.sp)

            CategorySelection(
                categories = sneakersCategories.categories,
                selectedCategory = viewModel.selectedCategory,
                onCategorySelected = { category ->
                    viewModel.selectedCategory = category

                    if (category != null) {
                        navController.navigate("categorySneakers_screen")
                    }
                }
            )
        }

        OverSmth("Популярное", navController)
        SneakerSelection(sneakers = sneakers, viewModel)
        SalesBar()
        BottomNavigationBar(navController)
    }
}
